@@ -13,7 +13,7 @@ class sidebar_module_quick_access(TabBase):
     def initialize(self, Network_UI):
         if Network_UI.network['STDP', 0] is not None:
             def learning_on_off(event):
-                Network_UI.network.set_mechanisms(['STDP'], self.stdp_cb.isChecked())
+                Network_UI.network.set_behaviours('STDP', self.stdp_cb.isChecked())
                 Network_UI.add_event('STDP ('+str(self.stdp_cb.isChecked())+')')
 
             self.stdp_cb = QCheckBox()
@@ -44,18 +44,21 @@ class sidebar_grammar_module_new(TabBase):
 
         if Network_UI.network['Text_Activator', 0] is not None:
             self.inp_text_label = QLabel(Network_UI.main_window)
-            Network_UI.Add_Sidebar_Element(self.inp_text_label, stretch=2)
+            Network_UI.sidebar.add_widget(self.inp_text_label, stretch=2)
+            #Network_UI.Add_Sidebar_Element()
             self.inp_text_label.setText('')
             self.inp_text_label.setFont(QFont("Courier"))
             self.inp_text_label.setToolTip('current network input')
 
         if Network_UI.network['Text_Reconstructor', 0] is not None:
             rl = QLabel(Network_UI.main_window)
-            Network_UI.Add_Sidebar_Element(rl, stretch=2)
+            Network_UI.sidebar.add_widget(rl, stretch=2)
+            #Network_UI.Add_Sidebar_Element(rl, stretch=2)
             rl.setText('Reconstruction:')
 
             self.recon_text_label = QLabel(Network_UI.main_window)
-            Network_UI.Add_Sidebar_Element(self.recon_text_label, stretch=2)
+            Network_UI.sidebar.add_widget(self.recon_text_label, stretch=2)
+            #Network_UI.Add_Sidebar_Element(self.recon_text_label, stretch=2)
             self.recon_text_label.setText('')
             self.recon_text_label.setFont(QFont("Courier"))
             self.recon_text_label.setToolTip('simple reconstruction text')
@@ -99,7 +102,7 @@ class sidebar_grammar_module(TabBase):
             # self.Add_Sidebar_Spacing()
 
             def learning_on_off(event):
-                Network_UI.network.set_mechanisms(['STDP'], self.stdp_cb.isChecked())
+                Network_UI.network.set_behaviours('STDP', self.stdp_cb.isChecked())
 
             self.stdp_cb = QCheckBox()
             self.stdp_cb.setText('STDP')
