@@ -56,18 +56,23 @@ def zipDir(dirPath, zipPath, filter=[]):
     zipf.close()
 
 def add_project_root_path():
-    root = get_root_folder().replace('/', '\\')
+    root = get_root_folder()#.replace('/', '\\')
 
     #add root folder (folder that contains Data folder) to import paths for easier import management
     if root not in sys.path:
         sys.path.append(root)
 
     # if project is a copy inside of a Data folder of the original project (e.g. Evolution_Project_Clones), ten remove the original folder from import paths
-    if '\\Data\\' in root:
+    if '\\Data\\' in root:#windows
         original_project_folder = root[0:root.find('\\Data\\')]
         if original_project_folder in sys.path:
             sys.path.remove(original_project_folder)
 
+    if '/Data/' in root:#linux
+        original_project_folder = root[0:root.find('/Data/')]
+        if original_project_folder in sys.path:
+            sys.path.remove(original_project_folder)
+
 
 #searches for "Data" folder in project by default
 #default folder: .../Data/StorageManager/main_folder_name/folder_name/
@@ -83,6 +88,17 @@ class StorageManager:
     def get_path(self):
         return self.absolute_path
 
+    def _create_StorageManager_Main_Folder(self, data_folder):
+        storage_manager_folder = data_folder +'/StorageManager/'
+
+        if not os.path.exists(storage_manager_folder):
+            try:
+                os.mkdir(storage_manager_folder)
+            except:
+                print('SM folder already exists...')
+
+        return storage_manager_folder
+
     def __init__(self, main_folder_name, folder_name=None, random_nr=False, print_msg=True, add_new_when_exists=True, data_folder=get_data_folder(), use_evolution_path=True):
 
         #when evolution is active, all storage managers with use_evolution_path=True will automatically save all data in the right evolution folder
@@ -99,13 +115,9 @@ class StorageManager:
         if type(main_folder_name) is dict:
             main_folder_name = self.dict_to_folder_name(main_folder_name)
 
-        storage_manager_folder = data_folder +'/StorageManager/'
 
-        if not os.path.exists(storage_manager_folder):
-            try:
-                os.mkdir(storage_manager_folder)
-            except:
-                print('SM folder already exists...')
+        storage_manager_folder = self._create_StorageManager_Main_Folder(data_folder)
+
 
         if folder_name is None:
             folder_name = main_folder_name
@@ -305,8 +317,12 @@ class SimpleStorageManager(StorageManager):
         self.frame_counter = {}
 
 
+
 class StorageManagerGroup:
 
+    def __iter__(self):
+        return self.StorageManagerList.__iter__()
+
     def __init__(self, Tag, main_folder_name=None, data_folder=get_data_folder()):
 
         storage_manager_folder = data_folder + '/StorageManager/'
@@ -398,6 +414,7 @@ class StorageManagerGroup:
 
         return result
 
+
     def get_all_params(self, section='Parameters', include_virtual_parameters=True):
         result_dict = {}
         for sm in self.StorageManagerList:
